@@ -1,4 +1,4 @@
-/* $Header: /var/lib/cvs/src/d2c/runtime/c-code/main.c,v 1.25 2003/07/17 19:19:40 housel Exp $ */
+/* $Header: /scm/cvs/src/d2c/runtime/c-code/main.c,v 1.28 2003/12/05 08:14:32 brent Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -72,16 +72,23 @@ void string_arg (char *arg) {
   descriptor_t tmp;
   descriptor_t *stack = gdb_stack_stack[gdb_stack_stack_index];
   void **dylan_str;
+  size_t len = 0;
 
   if (stack == 0)
     stack = gdb_stack_stack[gdb_stack_stack_index]
       = (descriptor_t *) malloc(GDB_STACK_SIZE);
+  len = strlen(arg);
+  if (*(arg + len) != 0) {
+	  /* provide space for a null-terminator */
+	  len++;
+  }
 
   dylan_str = (void **)
-    GC_malloc(sizeof(struct heapobj *) + sizeof(long) + strlen(arg));
+    GC_malloc(sizeof(struct heapobj *) + sizeof(long) + len);
   dylan_str[0] = (void *)(&dylanZdylan_visceraZCLS_byte_string_HEAP);
-  dylan_str[1] = (void *)strlen(arg);
-  strcpy((char *)(&dylan_str[2]), arg);
+  dylan_str[1] = (void *)len;
+  strncpy((char *)(&dylan_str[2]), arg, len);
+  *((char*)(&dylan_str[2]) + len) = 0;
 
   tmp.heapptr = (struct heapobj *)dylan_str;
   tmp.dataword.l = 0;
@@ -186,6 +193,9 @@ void no_core_dumps(void)
   getrlimit(RLIMIT_CORE, &lim);
   lim.rlim_cur = 0;
   setrlimit(RLIMIT_CORE, &lim);
+  lim.rlim_cur = RLIM_INFINITY;
+  lim.rlim_max = RLIM_INFINITY;
+  setrlimit(RLIMIT_STACK, &lim);
 }
 #else
 void no_core_dumps(void)
